@@ -16,8 +16,8 @@ This library is published under the MIT License.
 from .core.CartographySelector import CartographySelector
 from .core.CrossFader import CrossFader
 from .core.Fader import Fader
-from .core.FittestMeasureMaker import FittestMeasureMaker
 from .core.GeneticAlgorithm import GeneticAlgorithm
+from .core.GeneticAlgorithmMusicMaker import GeneticAlgorithmMusicMaker
 from .core.Hocketer import Hocketer
 from .core.LeafLooper import LeafLooper
 from .core.ListLooper import ListLooper
@@ -30,28 +30,32 @@ from .core.WindowLooper import WindowLooper
 
 from .indicators.TimeSignature import TimeSignature
 
+from .makers.LeafDynMaker import LeafDynMaker
+
 from .score.ArtificialHarmonic import ArtificialHarmonic
 from .score.HarmonicNote import HarmonicNote
-from .score.LeafDynMaker import LeafDynMaker
+from .score.Score import Score
 
 from .spanners.half_piano_pedal import half_piano_pedal
 from .spanners.piano_pedal import piano_pedal
 
+from .utilities.staff_splitter import staff_splitter
+
 from . import get
 
 from . import mutate
 
 
 __author__ = "Gilberto Agostinho <gilbertohasnofb@gmail.com>"
-__version__ = "0.9.0"
+__version__ = "0.9.2"
 __all__ = [
     '__author__',
     '__version__',
     'CartographySelector',
     'CrossFader',
     'Fader',
-    'FittestMeasureMaker',
     'GeneticAlgorithm',
+    'GeneticAlgorithmMusicMaker',
     'Hocketer',
     'LeafLooper',
     'ListLooper',
@@ -62,11 +66,13 @@ __all__ = [
     'TenneySelector',
     'WindowLooper',
     'TimeSignature',
+    'LeafDynMaker',
     'ArtificialHarmonic',
     'HarmonicNote',
-    'LeafDynMaker',
+    'Score',
     'half_piano_pedal',
     'piano_pedal',
+    'staff_splitter',
     'get',
     'mutate',
 ]
