@@ -7,9 +7,9 @@ from .. import get, mutate
 
 
 class Shuffler:
-    r"""This class takes an input |abjad.Container| (or child class) and
-    shuffles or rotates its logical ties or pitches. When shuffling or rotating
-    pitches only, tuplets are supported, otherwise tuplets are not supported.
+    r"""Takes an |abjad.Container| (or child class) and shuffles or rotates its
+    logical ties or pitches. When shuffling or rotating pitches only, tuplets
+    are supported, otherwise tuplets are not supported.
 
     Basic usage:
         Calling the object will output a shuffled selection of the input
@@ -1514,7 +1514,7 @@ class Shuffler:
         dummy_container[:] = []
         self._update_logical_selections()
         self._get_pitch_list()
-        self._time_signatures = get.extract_time_signatures(
+        self._time_signatures = get.time_signature_list(
             self._contents,
             do_not_use_none=True,
         )
