@@ -10,7 +10,7 @@ def test_CrossFader_01():
     fade_out_container = abjad.Staff(r"fs'4 g'2 bf'4")
     fade_in_container = abjad.Staff(r"\times 4/5 {cs''4 d''1}")
     fader = auxjad.CrossFader(fade_out_container, fade_in_container)
-    assert format(fader) == abjad.String.normalize(
+    assert abjad.lilypond(fader) == abjad.String.normalize(
         r"""
         \new Staff
         {
@@ -21,7 +21,8 @@ def test_CrossFader_01():
         }
         \new Staff
         {
-            \times 4/5 {
+            \times 4/5
+            {
                 \time 4/4
                 cs''4
                 d''1
@@ -33,7 +34,7 @@ def test_CrossFader_01():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -56,7 +57,7 @@ def test_CrossFader_01():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -69,7 +70,8 @@ def test_CrossFader_01():
             }
             \new Staff
             {
-                \times 4/5 {
+                \times 4/5
+                {
                     \time 4/4
                     r4
                     d''1
@@ -82,7 +84,7 @@ def test_CrossFader_01():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -95,7 +97,8 @@ def test_CrossFader_01():
             }
             \new Staff
             {
-                \times 4/5 {
+                \times 4/5
+                {
                     \time 4/4
                     r4
                     d''1
@@ -136,7 +139,7 @@ def test_CrossFader_03():
     selection_a, selection_b = fader()
     staff_a.extend(selection_a)
     staff_b.extend(selection_b)
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -163,12 +166,14 @@ def test_CrossFader_03():
             {
                 \time 4/4
                 R1
-                \times 4/5 {
+                \times 4/5
+                {
                     \time 4/4
                     cs''4
                     r1
                 }
-                \times 4/5 {
+                \times 4/5
+                {
                     \time 4/4
                     cs''4
                     r1
@@ -190,7 +195,7 @@ def test_CrossFader_04():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -217,23 +222,28 @@ def test_CrossFader_04():
             {
                 \time 4/4
                 R1
-                \times 4/5 {
+                \times 4/5
+                {
                     cs''4
                     r1
                 }
-                \times 4/5 {
+                \times 4/5
+                {
                     cs''4
                     r1
                 }
-                \times 4/5 {
+                \times 4/5
+                {
                     cs''4
                     d'1
                 }
-                \times 4/5 {
+                \times 4/5
+                {
                     cs''4
                     d'1
                 }
-                \times 4/5 {
+                \times 4/5
+                {
                     cs''4
                     d'1
                 }
@@ -252,7 +262,7 @@ def test_CrossFader_05():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -296,7 +306,7 @@ def test_CrossFader_06():
     for selection_a, selection_b in fader:
         staff_a.extend(selection_a)
         staff_b.extend(selection_b)
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -360,7 +370,7 @@ def test_CrossFader_07():
         selection_a, selection_b = next(fader)
         staff_a.extend(selection_a)
         staff_b.extend(selection_b)
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -403,7 +413,7 @@ def test_CrossFader_08():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -444,7 +454,7 @@ def test_CrossFader_08():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -487,7 +497,7 @@ def test_CrossFader_08():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -536,7 +546,7 @@ def test_CrossFader_09():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -637,7 +647,7 @@ def test_CrossFader_09():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -743,7 +753,7 @@ def test_CrossFader_10():
     fade_in_container = abjad.Container(r"\time 3/4 c'8 d' e' f' g' a'")
     fader = auxjad.CrossFader(fade_out_container, fade_in_container)
     fader.fade_out_contents = abjad.Container(r"\time 3/4 a4. bf4.")
-    assert format(fader) == abjad.String.normalize(
+    assert abjad.lilypond(fader) == abjad.String.normalize(
         r"""
         {
             %%% \time 3/4 %%%
@@ -776,7 +786,7 @@ def test_CrossFader_11():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -836,7 +846,7 @@ def test_CrossFader_12():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -885,7 +895,7 @@ def test_CrossFader_13():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -949,7 +959,7 @@ def test_CrossFader_14():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -969,7 +979,8 @@ def test_CrossFader_14():
             {
                 R1
                 R1
-                \times 4/5 {
+                \times 4/5
+                {
                     cs''4
                     r1
                 }
@@ -991,7 +1002,7 @@ def test_CrossFader_15():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -1039,9 +1050,9 @@ def test_CrossFader_16():
     selection_a, selection_b = fader.output_all()
     staff_a = abjad.Staff(selection_a)
     staff_b = abjad.Staff(selection_b)
-    auxjad.mutate([staff_a, staff_b]).sync_containers()
+    auxjad.mutate.sync_containers([staff_a, staff_b])
     score = abjad.Score([staff_a, staff_b])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -1156,7 +1167,7 @@ def test_CrossFader_18():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
@@ -1193,20 +1204,23 @@ def test_CrossFader_18():
             {
                 \time 4/4
                 R1
-                \times 2/3 {
+                \times 2/3
+                {
                     f'4
                     \pp
                     - \staccato
                     r2
                 }
                 r2
-                \times 2/3 {
+                \times 2/3
+                {
                     f'4
                     - \staccato
                     r2
                 }
                 r2
-                \times 2/3 {
+                \times 2/3
+                {
                     f'4
                     - \staccato
                     r4
@@ -1216,7 +1230,8 @@ def test_CrossFader_18():
                     ~
                 }
                 d'2
-                \times 2/3 {
+                \times 2/3
+                {
                     f'4
                     \pp
                     - \staccato
@@ -1246,38 +1261,45 @@ def test_CrossFader_19():
         abjad.Staff(selection_a),
         abjad.Staff(selection_b),
     ])
-    assert format(score) == abjad.String.normalize(
+    assert abjad.lilypond(score) == abjad.String.normalize(
         r"""
         \new Score
         <<
             \new Staff
             {
-                \times 2/3 {
+                \times 2/3
+                {
                     \time 4/4
                     <c' e'>2
                     g'1
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     <c' e'>2
                     g'1
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     <c' e'>2
                     g'1
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     <c' e'>2
                     g'1
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     c'2
                     g'1
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     c'2
                     g'1
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     c'2
                     r1
                 }
@@ -1320,7 +1342,7 @@ def test_CrossFader_20():
         [abjad.Voice(selection_a), abjad.Voice(selection_b)],
         simultaneous=True,
     )
-    assert format(staff) == abjad.String.normalize(
+    assert abjad.lilypond(staff) == abjad.String.normalize(
         r"""
         \new Staff
         <<
@@ -1361,31 +1383,37 @@ def test_CrossFader_20():
                 \voiceTwo
                 R1
                 R1
-                \times 2/3 {
+                \times 2/3
+                {
                     r1
                     c'2
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     e'2
                     r2
                     c'2
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     e'2
                     d'2
                     c'2
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     e'2
                     d'2
                     c'2
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     e'2
                     d'2
                     c'2
                 }
-                \times 2/3 {
+                \times 2/3
+                {
                     e'2
                     d'2
                     c'2
